# damply

[![codecov](https://codecov.io/gh/bhklab/damply/graph/badge.svg?token=tCcajRIGz9)](https://codecov.io/gh/bhklab/damply)
[![CI-CD](https://github.com/bhklab/damply/actions/workflows/main.yaml/badge.svg)](https://github.com/bhklab/damply/actions/workflows/main.yaml)
[![CodeFactor](https://www.codefactor.io/repository/github/bhklab/damply/badge)](https://www.codefactor.io/repository/github/bhklab/damply)

[![pixi-badge](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/prefix-dev/pixi/main/assets/badge/v0.json&style=flat-square)](https://github.com/prefix-dev/pixi)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&style=flat-square)](https://github.com/pre-commit/pre-commit)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=flat-square)](https://github.com/astral-sh/ruff)
[![Built with Material for MkDocs](https://img.shields.io/badge/mkdocs--material-gray?logo=materialformkdocs&style=flat-square)](https://github.com/squidfunk/mkdocs-material)

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/damply)](https://pypi.org/project/damply/)
[![PyPI - Version](https://img.shields.io/pypi/v/damply)](https://pypi.org/project/damply/)
[![PyPI - Format](https://img.shields.io/pypi/format/damply)](https://pypi.org/project/damply/)
[![Downloads](https://static.pepy.tech/badge/damply)](https://pepy.tech/project/damply)

## Overview

DaMPly (Data Management Plan) is a Python module designed to streamline
the implementation and management of DMP compliant projects.
